package org.galaxy.service.modelfragment;

import java.io.IOException;
import java.util.List;

import javax.activation.DataHandler;

import org.galaxy.utility.filerepository.IOFragmentException;
import org.galaxy.utility.fragmentanalyser.MalformedFragmentException;

/**
 * This interface contains services in order to manage manage publication of Model Fragment on Galaxy server
 *
 */
public interface IModelFragmentManagement {
	
	
	/**
	 * Takes a Model Fragment object and publishes it in the Galaxy repository, 
	 * as a single archive file
	 * @param fragmentTransfer Model Fragment in xs:base64Binary format 
	 * @throws IOException 
	 */
	public Integer publish(DataHandler fragmentHandler) throws IOException,MalformedFragmentException,IOFragmentException;

	/**
	 * Retrieves a Model Fragment from the Galaxy repository, based on its id.
	 * @param modelFragmentQualifiedName  Model Fragment name
	 * @param version  Model Fragment version
	 * @return Model Fragment in xs:base64Binary format 
	 * @throws IOException 
	 */
	public DataHandler retrieve(String modelFragmentQualifiedName, String version) throws IOException,IOFragmentException; 
	
	
	/**
	 * Return list of all Model Fragment in Galaxy repository
	 * @return List of Model Fragment Data
	 * @throws IOException 
	 */
	public List<ModelFragmentData> findAllModelFragments() throws IOException;
	
	
	
	/**
	 * Return Model Fragment in Galaxy repository
	 * @param modelFragmentQualifiedName  Model Fragment name
	 * @param version  Model Fragment version
	 * @return Model Fragment Data
	 * @throws IOException 
	 */
	public ModelFragmentData findModelFragmentById(String modelFragmentQualifiedName, String version) throws IOException;
	
	
	/**
	 * Return List ofModel Fragment in Galaxy repository
	 * @param modelfragmentIds set ModelFragmentData with Name and Version initialised
	 * @return Model Fragment Data
	 * @throws IOException 
	 */
	public List<ModelFragmentData> findModelFragmentByIds(List<ModelFragmentData> modelfragmentIds) throws IOException;
	
	
	/**
	 * Return a subset of Model Fragment in Galaxy repository
	 * The Model Fragment list  is filtered based on patterns namePattern and versionPattern
	 * @param modelfragmentIds Pattern for names of requested Model Fragment
	 * @param versionPattern Pattern for version of requested Model Fragment
	 * @return List of Model Fragment Data
	 * @throws IOException 
	 */
	public List<ModelFragmentData> findModelFragmentsByNameAndVersion(String namePattern,String versionPattern) throws IOException,InvalidPatternException;

	
	
	/**
	 * Deletes the given ModelFragment from the system
	 * @param modelFragmentQualifiedName  Model Fragment name
	 * @param version  Model Fragment version
	 * @throws IOException 
	 */
	public void deleteModelFragment(String modelFragmentQualifiedName, String version) throws IOException,IOFragmentException;


	/**
	 * Delete the given ModelFragment from the system
	 * @param modelfragmentIds set ModelFragmentData with Name and Version initialised
	 * @throws IOException 
	 */
	public void deleteModelFragments(List<ModelFragmentData> modelfragmentIds) throws IOException,IOFragmentException;
}
