package org.galaxy.service.rolemanagement;

import java.io.IOException;
import java.util.List;
/**
 * This interface contains services in order to manage roles.
 */
public interface IRoleManagement {

	/**
	 * List all role of specified project.
	 * @param projectId Identifier of project
	 * @return List of Role Data
	 * @throws IOException 
	 */
	public List<Role> findRolesByProject(Integer projectId) throws IOException;

	/**
	 * List all existing role.
	 * @return List of role
	 */
	public List<Role> findAllRoles() throws IOException;

	/**
	 * Find a role identified by  his Identifier
	 * @param roleId Identifier of role
	 * @return Role Data
	 * @throws IOException 
	 */
	public Role findRoleById(Integer roleId) throws IOException;
	
	/**
	 * Find List of role identified by  her Identifier
	 * @param roleId List of Role's identifier
	 * @return List of Rol's data
	 * @throws IOException 
	 */
	public List<Role> findRoleByIds(List<Integer> roleIds) throws IOException;

	/**
	 * List all role of participantId in specified project.
	 * @param projectId Identifier of project
	 * @param participantId Identifier of participant
	 * @return List of Role Data
	 * @throws IOException 
	 */
	public List<Role> findRolesByProjectAndParticipant(Integer porjectId,Integer participantId) throws IOException;

	/**
	 * Creates a new role in the system .It returns the id of role
	 * @param project Role Data
	 * @return Identifier of role
	 * @throws IOException 
	 */
	public Integer createRole(Role role) throws IOException;

	/**
	 * Delete the given role from the system
	 * @param roleId Identifier of role
	 * @throws IOException 
	 */
	public void deleteRole(Integer roleId) throws IOException;

	/**
	 * Delete the given roles from the system
	 * @param roleIds Identifier of roles
	 * @throws IOException 
	 */
	public void deleteRoles(List<Integer> roleIds) throws IOException;

	/**
	 * Update the given role from the system
	 * @param role Role Data
	 * @throws IOException 
	 */
	public void updateRole(Role role) throws IOException;
	
	
	
}
