package org.galaxy.service.usermanagement;

import java.io.IOException;
import java.util.List;

/**
 * This interface contains services in order to manage users.
 */
public interface IUserManagement{

	/**
	 * Creates a new participant with the given name.
	 * @param participant Participant Data
	 * @return Identifier of new participant
	 * @throws IOException 
	 */
	public Integer createParticipant(Participant participant) throws IOException;

	
	/**
	 * Update the given participant from the system
	 * @param participant Participant Data
	 * @throws IOException 
	 */
	public void updateParticipant(Participant participant) throws IOException;

	/**
	 * Delete the given participant from the system
	 * @param participantId Identifier of participant
	 * @throws IOException 
	 */
	public void deleteParticipant(Integer participantId) throws IOException;

	
	/**
	 * Find a participant identified by  his Identifier
	 * @param participantId Identifier of participant
	 * @return Participant Data
	 * @throws IOException 
	 */
	public Participant findParticipantById(Integer participantId) throws IOException;
	
	/**
	 * List all the existing participant.
	 * @return List of participant
	 */
	public List<Participant> findAllParticipants() throws IOException;


	/**
	 * List all participant of specified project.
	 * @param projectId Identifier of project
	 * @return List of Participant Data
	 * @throws IOException 
	 */
	public List<Participant> findParticipantsByProject(Integer projectId) throws IOException;


	/**
	 * List all participant of specified project whith specified roles.
	 * @param projectId Identifier of project
	 * @param roleId List of role identifier
	 * @return List of Participant Data
	 * @throws IOException 
	 */
	public List<Participant> findParticipantsByProjectAndRoles(Integer projectId,List<Integer> roleIds) throws IOException;


	/**
	 * List all participant of specified workgroup.
	 * @param workgroupId Identifier of workgroup
	 * @return List of Participant Data
	 * @throws IOException 
	 */
	public List<Participant> findParticipantsByWorkgroup(Integer workgroupId) throws IOException;


	
	/**
	 * Delete the givens participants from the system
	 * @param participantIds LIst of participants Identifiers 
	 * @throws IOException 
	 */
	public void deleteParticipants(List<Integer> participantIds) throws IOException;
	
	
	/**
	 * Find  participants identified by ther Identifier
	 * @param participantIds Identifier of participant
	 * @return List of Participant
	 * @throws IOException 
	 */
	public List<Participant> findParticipantsByIds(List<Integer> participantIds)throws IOException;


}
