package org.galaxy.service.workgroupmanagement;

import java.io.IOException;
import java.util.List;


/**
 * This interface contains services in order to manage workgroup.
 */
public interface IWorkgroupManagement{
	
	/**
	 * Add specified Participant to specified Workgroup
	 * @param workgroupId Identifier of Workgroup
	 * @param participantId Identifier of Participant
	 * @throws IOException 
	 */
	public void addParticipant(Integer workgroupId,Integer participantId) throws IOException;
	
	
	/**
	 * Remove specified Participant of specified Workgroup
	 * @param workgroupId Identifier of Workgroup
	 * @param participantId Identifier of Participant
	 * @throws IOException 
	 */
	public void removeParticipant(Integer workgroupId, Integer participantId) throws IOException;

	
	/**
	 * Find a workgroup identified by  his Identifier
	 * @param workgroupId Identifier of workgroup
	 * @return Workgroup Data
	 * @throws IOException 
	 */
	public Workgroup findWorkgroupById(Integer workgroupId) throws IOException;
	
	
	/**
	 * List all existing workgroup.
	 * @return List of workgroup
	 */
	public List<Workgroup> findAllWorkgroups() throws IOException;


	/**
	 * List all workgroup of specified participant.
	 * @return List of workgroup
	 * @throws IOException 
	 */
	public List<Workgroup> findWorkgroupsByParticipant(Integer participantId) throws IOException;
	
	/**
	 * Add specified Participants to specified Workgroup
	 * @param workgroupId identifiers of workgroups
	 * @param participantIds List of Participant's identifiers 
	 * @throws IOException
	 */
	public void addParticipants(Integer workgroupId, List<Integer> participantIds) throws IOException;
	
	/**
	 * Remove specified Participants of specified Workgroup
	 * @param workgroupId identifiers of workgroups
	 * @param participantIds List of Participant's identifiers
	 * @throws IOException 
	 */
	public void removeParticipants(Integer workgroupId, List<Integer> participantIds) throws IOException;
	
	/**
	 * Find  workgroups identified by her identifiers
	 * @param workgroupsIds List of Workgroup's identifiers
	 * @return A Workgroup
	 * @throws IOException
	 */
	public List<Workgroup> findWorkgroupsByIds(List<Integer> workgroupsIds) throws IOException;


	/**
	 * Creates a new group in the system. 
	 * @param workgroup Workgroup Data 
	 * @return Identifier of new Workgroup
	 * @throws IOException 
	 */
	public Integer createWorkgroup(Workgroup workgroup) throws IOException;


	/**
	 * Deletes the given workgroup from the system
	 * @param workgroupId Identifier of workgroup
	 * @throws IOException 
	 */
	public void deleteWorkgroup(Integer workgroupId) throws IOException;


	/**
	 * Delete the given workgroups from the system
	 * @param workgroupIds Identifier of workgroups
	 * @throws IOException 
	 */
	public void deleteWorkgroups(List<Integer> workgroupIds) throws IOException;


	/**
	 * Update the given workgroup from the system
	 * @param workgroup  Workgroup Data
	 * @throws IOException 
	 */
	public void updateWorkgroup(Workgroup workgroup) throws IOException;
}
