package org.galaxy.utility.fragmentanalyser;

import java.io.File;

import javax.ejb.Remote;
import javax.ejb.Stateless;

import org.galaxy.i18n.Messages;
import org.galaxy.modelfragment.schema.ModelFragment;
import org.galaxy.modelfragment.utils.ModelFragmentUtils;

/**
 * Implementation of IFragmentAnalyser services dedicated to ModelFragment manipulation
 */
@Remote
@Stateless
public class FragmentAnalyser implements IFragmentAnalyser {

	@Override
	public void validate(File fragmentmetadata)
			throws MalformedFragmentException {

		try {
			ModelFragment metadata =  ModelFragmentUtils.unpackageFragment(fragmentmetadata, File.createTempFile("ModelFragmentUnzip", ""));
			if(metadata == null){
				throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA","metadata not found"));
			}
			
			validateMetadata(metadata);
			
		} catch (Exception e) {
			throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA"));
		}
		
	}
	
	
	public void validateMetadata(ModelFragment metadata)
			throws MalformedFragmentException {
		
			if(metadata == null){
				throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA", "metadata missing"));
			}

			if(metadata.getName() == null){
				throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA", "name missing"));
			}
			
			if(metadata.getDescription()== null){
				throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA", "description missing "));
			}
			
			if(metadata.getVersion() == null){
				throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA", "version missing"));
			}
			
			if(metadata.getId()== null){
				throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA", "name galaxy id"));
			}
	}

	@Override
	public ModelFragment extractMetadata(File fragment)
			throws MalformedFragmentException {
		ModelFragment metadata = null;
		try {
			File tempDirectory = new File(fragment.getAbsolutePath().replace(".zip", "Unzip"));
			tempDirectory.mkdirs();
			metadata = ModelFragmentUtils.unpackageFragment(fragment,tempDirectory);
		} catch (Exception e) {
			throw new MalformedFragmentException(Messages.getString("MALFROMEDFRAGMENT_METADATA"));
		}
		
		validateMetadata(metadata);
		
		return metadata;
	}

}
